package com.care.call.service.impl;


import com.care.call.entity.KoalaLogDomain;
import com.care.call.entity.KoalaLoggerEntity;
import com.care.call.mapper.KoalaOutCallLogRecordDao;
import com.care.call.service.KoalaOutCallLogRecordService;
import com.care.util.DateUtils;
import com.care.util.JsonUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Map;

/**
 * @author stw
 * @version 2.7.0 创建于 2019/7/15
 **/
@Service
public class KoalaOutCallLogRecordServiceImpl implements KoalaOutCallLogRecordService {

    @Autowired
    private KoalaOutCallLogRecordDao koalaOutCallLogRecordDao;

    @Override
    public void addOptLog(KoalaLoggerEntity koalaLoggerEntity) throws Exception {
        koalaOutCallLogRecordDao.addOptLog(makeLog(koalaLoggerEntity));
    }

    private static Map<String, Object> parseJson(String json) throws Exception {
        return JsonUtil.fromJson(json, Map.class);
    }

    private KoalaLogDomain makeLog(KoalaLoggerEntity koalaLoggerEntity) throws Exception {
        //前端调用接口即触发日志记录事件
        KoalaLogDomain domain = new KoalaLogDomain();
        domain.setResult(koalaLoggerEntity.getResult());
        domain.setApiMethod(koalaLoggerEntity.getApiMethod());
        domain.setComputeTraffic("0");//话单未被计算

        domain.setAgentId(koalaLoggerEntity.getAgentId());
        domain.setEntNo(koalaLoggerEntity.getEntNo());
        domain.setTaskId(koalaLoggerEntity.getTaskId());
        domain.setDisNumber(koalaLoggerEntity.getDisNumber());

        //解析请求结果，获取sessionId和坐席分机号等
        Map<String, Object> map = parseJson(koalaLoggerEntity.getResult());
        Object sessionId = map.get("callID");
        Object agentNumber = map.get("thisDN");
        Object receiveTime = map.get("creationTime");
        Object tenantId = map.get("tenantID");
        Object messageId = map.get("messageId");
        Object callState = map.get("callState");//0：被叫挂断，1：主叫挂断
        Object calledNumber = map.get("otherDN");//被叫号码
        if(sessionId != null){
            domain.setSessionId(sessionId.toString());
        }
        if(agentNumber != null){
            domain.setAgentNumber(agentNumber.toString());
        }
        if(receiveTime != null){
            domain.setReceiveTime(DateUtils.formatMillisecondTime(receiveTime.toString()));
        }
        if(tenantId != null){
            domain.setTenantId(tenantId.toString());
        }
        if(messageId != null){
            //根据考拉外呼messageId确定事件状态
            //1.坐席振铃,2.坐席接通,3.客户振铃,4.客户接通,5.坐席挂断,6.客户挂断,7.未接通'
            //callState为空，默认认为是被叫挂断（用于挂断状态处理）
            domain.setEventStatus(formatOutCallEvent(messageId.toString(), (callState != null) ? callState.toString() : "1"));
        }
        if(calledNumber != null){
            domain.setCalledNumber(calledNumber.toString());
        }
        return domain;
    }

    /**
     * 根据考拉外呼messageId确定事件状态
     * @param messageId
     * @return
     */
    private String formatOutCallEvent(String messageId, String callState){
        //1.坐席振铃,2.坐席接通,3.客户振铃,4.客户接通,5.坐席挂断,6.客户挂断,7.未接通'
        String eventStatus = "";
        switch (messageId){
            case "505":
                eventStatus = "1";
                break;
            case "506":
                eventStatus = "4";
                break;
            case "515":
                eventStatus = "6";
                if("1".equals(callState)){
                    eventStatus = "5";
                }
                break;
            default:
                eventStatus = "7";
                break;
        }
        return eventStatus;
    }
}
